@@ -5,6 +5,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     ForeignKey,
+    Float,
 )
 
 from ...database import Base
@@ -24,6 +25,10 @@ class ConditionNewswireModel(Base):
         ForeignKey('conditions.id'),
         nullable=False,
     )
+    score = Column(
+        Float,
+        nullable=False,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
