@@ -13,6 +13,13 @@ class LicensingResourceSchema(Schema):
     originator_subsidiary_id = fields.Integer(required=True)
     target_subsidiary_id = fields.Integer(required=True)
     type = fields.String(validate=not_blank, required=True)
-    terms = fields.String()
+    terms = fields.String(allow_none=True)
+    is_deleted = fields.Boolean(allow_none=True)
+    updated_at = fields.DateTime()
+
+
+class LicensingPatchSchema(Schema):
+    not_blank = validate.Length(min=1, error='Field cannot be blank')
+    id = fields.Integer(required=True)
     is_deleted = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
