@@ -13,6 +13,13 @@ class NCTStudyResourceSchema(Schema):
     id = fields.Integer(dump_only=True)
     nct_id = fields.String(allow_none=False, validate=not_blank)
     brief_title = fields.String(allow_none=True)
+    brief_summary = fields.String(allow_none=True)
+    enrollment = fields.Integer(allow_none=True)
+    enrollment_type = fields.String(allow_none=True)
+    why_stopped = fields.String(allow_none=True)
+    primary_completion_date = fields.DateTime(allow_none=True)
+    primary_completion_date_type = fields.String(allow_none=True)
+    study_first_posted_date = fields.DateTime(allow_none=True)
     study_status = fields.String(allow_none=True)
     study_type = fields.String(allow_none=True)
     study_start_date = fields.DateTime(allow_none=True)
@@ -25,7 +32,7 @@ class NCTStudyResourceSchema(Schema):
 
     @pre_load
     def convert_string_to_datetime(self, in_data):
-        date_fields = ['study_start_date', 'last_update_submitted_qc_date']
+        date_fields = ['study_start_date', 'last_update_submitted_qc_date', 'study_first_posted_date', 'primary_completion_date']
 
         in_data = pre_load_date_fields(
             in_data,
