@@ -17,6 +17,7 @@ class NewswireResourceSchema(Schema):
     headline = fields.String(required=True)
     drugs = fields.String(allow_none=True)
     conditions = fields.String(allow_none=True)
+    concepts = fields.String(allow_none=True)
     filtered_drugs = fields.String(allow_none=True)
     filtered_conditions = fields.String(allow_none=True)
     news_file_id = fields.Integer(required=True)
@@ -44,6 +45,7 @@ class NewswireQueryParamsSchema(Schema):
     headline = fields.String()
     drugs = fields.String()
     conditions = fields.String()
+    concepts = fields.String()
     filtered_drugs = fields.String()
     filtered_conditions = fields.String()
 
@@ -68,6 +70,7 @@ class NewswirePatchSchema(Schema):
     headline = fields.String(allow_none=False)
     drugs = fields.String(allow_none=True)
     conditions = fields.String(allow_none=True)
+    concepts = fields.String(allow_none=True)
     filtered_drugs = fields.String(allow_none=True)
     filtered_conditions = fields.String(allow_none=True)
     news_file_id = fields.Integer(allow_none=True)
